@@ -12,7 +12,13 @@ JSON_TYPES = (
     dict,
 )  # list omitted to support list of custom types
 
-PASSTHROUGH_TYPES = {None, Any, *JSON_TYPES}
-
+PASSTHROUGH_TYPES = {None, Any, bytes, *JSON_TYPES}
 
 TypeHint = Any  # :shrug:
+
+
+def is_passthrough_type(obj: Any) -> bool:
+    try:
+        return obj in PASSTHROUGH_TYPES
+    except TypeError:
+        return False
